// src/backend/resource.cc - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#include "config.h"
#include "gettext.h"

#include "ready_queue.hh"

using sgpem::ReadyQueue;

void
ReadyQueue::swap(position a, position b)
	throw (std::out_of_range)
{
	size_t size = _scheds.size();
	if(a > size || b > size) 
		throw std::out_of_range(_("Trying to access a Schedulable "
															"with an index outside of the "
															"queue limits."));
	if(a == b) return;

	Schedulable* temp = _scheds[a];
	_scheds[a] = _scheds[b];
	_scheds[b] = temp;
}


ReadyQueue::size_t
ReadyQueue::size() const
{
	return _scheds.size();
}


sgpem::Schedulable&
ReadyQueue::get_item_at(position index)
	throw (std::out_of_range)
{
	if(index > size())
		throw std::out_of_range(_("Trying to access a Schedulable "
															"with an index outside of the "
															"queue limits."));
	return *(_scheds[index]);
}


void
ReadyQueue::append(Schedulable& schedulable)
{
	_scheds.push_back(&schedulable);
}
